==> RsFsw-5.20.1.tar.gz: RsFsw-5.20.1/RsFsw/Implementations/Calculate/Marker/Function/Toi/State.py <==
from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, state: bool, window=repcap.Window.Default, marker=repcap.Marker.Default) -> None:
		"""SCPI: CALCulate<n>:MARKer<m>:FUNCtion:TOI[:STATe] \n
		Snippet: driver.calculate.marker.function.toi.state.set(state = False, window = repcap.Window.Default, marker = repcap.Marker.Default) \n
		This command initiates a measurement to determine the third intercept point. A two-tone signal with equal carrier levels
		is expected at the RF input of the instrument. Marker 1 and marker 2 (both normal markers) are set to the maximum of the
		two signals. Delta marker 3 and delta marker 4 are positioned to the intermodulation products. The delta markers can be
		modified separately afterwards with the method RsFsw.Applications.K10x_Lte.Calculate.DeltaMarker.X.set command.
		The third-order intercept is calculated from the level spacing between the normal markers and the delta markers. \n
			:param state: ON | OFF | 1 | 0
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
		"""
		param = Conversions.bool_to_str(state)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		self._core.io.write(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:FUNCtion:TOI:STATe {param}')

	def get(self, window=repcap.Window.Default, marker=repcap.Marker.Default) -> bool:
		"""SCPI: CALCulate<n>:MARKer<m>:FUNCtion:TOI[:STATe] \n
		Snippet: value: bool = driver.calculate.marker.function.toi.state.get(window = repcap.Window.Default, marker = repcap.Marker.Default) \n
		This command initiates a measurement to determine the third intercept point. A two-tone signal with equal carrier levels
		is expected at the RF input of the instrument. Marker 1 and marker 2 (both normal markers) are set to the maximum of the
		two signals. Delta marker 3 and delta marker 4 are positioned to the intermodulation products. The delta markers can be
		modified separately afterwards with the method RsFsw.Applications.K10x_Lte.Calculate.DeltaMarker.X.set command.
		The third-order intercept is calculated from the level spacing between the normal markers and the delta markers. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
			:return: state: ON | OFF | 1 | 0"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:FUNCtion:TOI:STATe?')
		return Conversions.str_to_bool(response)

==> RsFsw-6.0.0.tar.gz: RsFsw-6.0.0/RsFsw/Implementations/Calculate/Marker/Function/Toi/State.py <==
from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, state: bool, window=repcap.Window.Default, marker=repcap.Marker.Default) -> None:
		"""SCPI: CALCulate<n>:MARKer<m>:FUNCtion:TOI[:STATe] \n
		Snippet: driver.calculate.marker.function.toi.state.set(state = False, window = repcap.Window.Default, marker = repcap.Marker.Default) \n
		Initiates a measurement to determine the third intercept point. A two-tone signal with equal carrier levels is expected
		at the RF input of the instrument. Marker 1 and marker 2 (both normal markers) are set to the maximum of the two signals.
		Delta marker 3 and delta marker 4 are positioned to the intermodulation products. The delta markers can be modified
		separately afterwards with the method RsFsw.Applications.K10x_Lte.Calculate.DeltaMarker.X.set command. The third-order
		intercept is calculated from the level spacing between the normal markers and the delta markers. \n
			:param state: ON | OFF | 1 | 0
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
		"""
		param = Conversions.bool_to_str(state)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		self._core.io.write(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:FUNCtion:TOI:STATe {param}')

	def get(self, window=repcap.Window.Default, marker=repcap.Marker.Default) -> bool:
		"""SCPI: CALCulate<n>:MARKer<m>:FUNCtion:TOI[:STATe] \n
		Snippet: value: bool = driver.calculate.marker.function.toi.state.get(window = repcap.Window.Default, marker = repcap.Marker.Default) \n
		Initiates a measurement to determine the third intercept point. A two-tone signal with equal carrier levels is expected
		at the RF input of the instrument. Marker 1 and marker 2 (both normal markers) are set to the maximum of the two signals.
		Delta marker 3 and delta marker 4 are positioned to the intermodulation products. The delta markers can be modified
		separately afterwards with the method RsFsw.Applications.K10x_Lte.Calculate.DeltaMarker.X.set command. The third-order
		intercept is calculated from the level spacing between the normal markers and the delta markers. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
			:return: state: ON | OFF | 1 | 0"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:FUNCtion:TOI:STATe?')
		return Conversions.str_to_bool(response)
